@@ -35,8 +35,8 @@ method create ($topic, $content, $tags, $created = DateTime->now) {
 method save ($post) {
     $post->{slug} = App::skryf::Util->slugify($post->{topic});
     $post->{html} = App::skryf::Util->convert($post->{content});
-    my $lt = localtime;
-    $post->{modified} = $lt;
+    my $lt = DateTime->now;
+    $post->{modified} = $lt->strftime('%Y-%m-%dT%H:%M:%SZ');
     $self->posts->save($post);
 }
 
@@ -55,3 +55,31 @@ method by_cat ($category) {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+App::skryf::Model::Post - Post Model Skryf
+
+=head1 DESCRIPTION
+
+Post model 
+
+=head1 METHODS
+
+=head2 B<posts>
+
+Posts collection
+
+=head1 SEE ALSO
+
+L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>. L<Mango>.
+
+=head1 COPYRIGHT AND LICENSE
+
+This plugin is copyright (c) 2013 by Adam Stokes <adamjs@cpan.org>
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
